<?php
/*
  $Id: address_book.php,v 1.2 2006/07/16 05:09:35 ryu Exp $

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2002 osCommerce

  Released under the GNU General Public License
  
  modified for Koshoten.net2
  http://www.koshoten.net/
*/

define('NAVBAR_TITLE_1', '');
define('NAVBAR_TITLE_2', 'ɥ쥹Ģ');
define('HEADING_TITLE', 'ɥ쥹Ģ');
define('TABLE_HEADING_NUMBER', 'No.');
define('TABLE_HEADING_NAME', '̾');
define('TABLE_HEADING_LOCATION', 'Ի');
define('TEXT_NO_ENTRIES_IN_ADDRESS_BOOK', 'ޤɥ쥹ĢϿϤޤ...');
define('TEXT_MAXIMUM_ENTRIES', ': ɥ쥹Ģˤ %s ޤϿǤޤ');
define('TEXT_MAXIMUM_ENTRIES_REACHED', ': ɥ쥹Ģ¤ %s ޤϿޤ');
?>